@@ -9,7 +9,7 @@ use Error::Pure qw(err);
 use Error::Pure::Utils;
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Error level.
 $Error::Pure::Utils::LEVEL = 5;
@@ -204,7 +204,8 @@ Tie::Hash::Check - Tied construct for hash key checking.
 
 =head1 DEPENDENCIES
 
-L<Error::Pure>.
+L<Error::Pure>,
+L<Error::Pure::Utils>.
 
 =head1 REPOSITORY
 
@@ -218,11 +219,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2009-2015 Michal Špaček
+ © 2009-2016 Michal Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
